# OctoprintPrinterData


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**job** | [**OctoprintJob**](OctoprintJob.md) |  | 
**state** | [**OctoprintPrinterState**](OctoprintPrinterState.md) |  | 
**user** | **str** |  | [optional] 
**current_z** | **float** |  | [optional] 
**progress** | [**OctoprintProgress**](OctoprintProgress.md) |  | 
**resends** | **dict(str, object)** |  | 
**offsets** | **dict(str, object)** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


